@@ -27,7 +27,7 @@
 #undef ARCH_ALIGN_DOUBLE
 #undef ARCH_ALIGN_INT64
 #define ASM_CFI_SUPPORTED
-#define PROFINFO_WIDTH 26
+#define PROFINFO_WIDTH 0
 #define CAML_WITH_CPLUGINS
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/lib/ocaml"
@@ -35,6 +35,7 @@
 #define HAS_C99_FLOAT_OPS
 #define HAS_GETRUSAGE
 #define HAS_TIMES
+#define HAS_SECURE_GETENV
 #define HAS_TERMCAP
 #define HAS_SOCKETS
 #define HAS_SOCKLEN_T
@@ -82,6 +83,9 @@
 #define HAS_GETHOSTBYADDR_R 8
 #define HAS_MKSTEMP
 #define HAS_NICE
+#define HAS_DUP3
+#define HAS_PIPE2
+#define HAS_ACCEPT4
 #define HAS_SIGWAIT
 #define HAS_LIBBFD
 #define HAS_HUGE_PAGES
